
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

/*
 * Copyright (C) 2002,2003 Mike McCormack
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifndef LIBMSI_ENUMS_H
#define LIBMSI_ENUMS_H

#include <glib-object.h>

G_BEGIN_DECLS
GType libmsi_result_error_get_type (void) G_GNUC_CONST;
#define LIBMSI_TYPE_RESULT_ERROR (libmsi_result_error_get_type ())
GType libmsi_property_type_get_type (void) G_GNUC_CONST;
#define LIBMSI_TYPE_PROPERTY_TYPE (libmsi_property_type_get_type ())
GType libmsi_col_info_get_type (void) G_GNUC_CONST;
#define LIBMSI_TYPE_COL_INFO (libmsi_col_info_get_type ())
GType libmsi_db_flags_get_type (void) G_GNUC_CONST;
#define LIBMSI_TYPE_DB_FLAGS (libmsi_db_flags_get_type ())
GType libmsi_db_error_get_type (void) G_GNUC_CONST;
#define LIBMSI_TYPE_DB_ERROR (libmsi_db_error_get_type ())
GType libmsi_property_get_type (void) G_GNUC_CONST;
#define LIBMSI_TYPE_PROPERTY (libmsi_property_get_type ())
G_END_DECLS

#endif

/* Generated data ends here */

